@@ -94,8 +94,12 @@ if is_single_transit == False:
 
 #Define the star parameters to calculate the planet parameters
 #Final values
-mstar_mean  = float(mstar) #0.870
-mstar_sigma = 0.1 #0.040
+try:
+	mstar_mean  = float(mstar) #0.870
+	mstar_sigma = 0.1 #0.040
+except:
+	mstar_mean  = 1 #0.870
+	mstar_sigma = 0.1 #0.040
 
 rstar_mean  = float(srad)
 rstar_sigma = 0.1 
